==> nextcloud-29.0.5.tgz: nextcloud/lib/l10n/bn_BD.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "\"config\" ডিরেক্টরিতে লেখা যায়না!",
    "See %s" : "%s দেখ",
    "Sample configuration detected" : "নমুনা কনফিগারেশন পাওয়া গেছে",
    "Unknown filetype" : "অজানা প্রকৃতির ফাইল",
    "Invalid image" : "অবৈধ চিত্র",
    "Files" : "ফাইল",
    "today" : "আজ",
    "yesterday" : "গতকাল",
    "last month" : "গত মাস",
    "last year" : "গত বছর",
    "seconds ago" : "সেকেন্ড পূর্বে",
    "__language_name__" : "বাংলা ভাষা",
    "Apps" : "অ্যাপ",
    "Settings" : "সেটিংস",
    "Log out" : "প্রস্থান",
    "Email" : "ইমেইল",
    "Phone" : "ফোন",
    "Website" : "ওয়েবসাইট",
    "Address" : "ঠিকানা",
    "About" : "সমপরকে",
    "You are not allowed to share %s" : "আপনি %s ভাগাভাগি করতে পারবেননা",
    "Sunday" : "রবিবার",
    "Monday" : "সোমবার",
    "Tuesday" : "মঙ্গলবার",
    "Wednesday" : "বুধবার",
    "Thursday" : "বৃহস্পতিবার",
    "Friday" : "শুক্রবার",
    "Saturday" : "শনিবার",
    "Sun." : "রবি.",
    "Mon." : "সোম.",
    "Tue." : "মঙ্গল.",
    "Wed." : "বুধ.",
    "Thu." : "বৃহঃ.",
    "Fri." : "শুক্র.",
    "Sat." : "শনি.",
    "January" : "জানুয়ারি",
    "February" : "ফেব্রুয়ারি",
    "March" : "মার্চ",
    "April" : "এপ্রিল",
    "May" : "মে",
    "June" : "জুন",
    "July" : "জুলাই",
    "August" : "অগাষ্ট",
    "September" : "সেপ্টেম্বর",
    "October" : "অক্টোবর",
    "November" : "নভেম্বর",
    "December" : "ডিসেম্বর",
    "Jan." : "জানু.",
    "Feb." : "ফেব্রু.",
    "Mar." : "মার্চ.",
    "Apr." : "এপ্রিল.",
    "May." : "মে.",
    "Jun." : "জুন.",
    "Jul." : "জুলাই.",
    "Aug." : "অগাস্ট.",
    "Sep." : "সেপ্টে.",
    "Oct." : "অক্টো.",
    "Nov." : "নভে.",
    "Dec." : "ডিসে.",
    "Application is not enabled" : "অ্যাপ্লিকেসনটি সক্রিয় নয়",
    "Authentication error" : "অনুমোদন ঘটিত সমস্যা",
    "Token expired. Please reload page." : "টোকেন মেয়াদোত্তীর্ণ। দয়া করে পৃষ্ঠাটি পূনরায় লোড করুন।",
    "Help" : "সহায়িকা",
    "Users" : "ব্যবহারকারী",
    "Unknown user" : "অপরিচিত ব্যবহারকারী"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.12p0.tgz: nextcloud/lib/l10n/bn_BD.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "\"config\" ডিরেক্টরিতে লেখা যায়না!",
    "See %s" : "%s দেখ",
    "Sample configuration detected" : "নমুনা কনফিগারেশন পাওয়া গেছে",
    "Unknown filetype" : "অজানা প্রকৃতির ফাইল",
    "Invalid image" : "অবৈধ চিত্র",
    "Files" : "ফাইল",
    "today" : "আজ",
    "yesterday" : "গতকাল",
    "last month" : "গত মাস",
    "last year" : "গত বছর",
    "seconds ago" : "সেকেন্ড পূর্বে",
    "__language_name__" : "বাংলা ভাষা",
    "Apps" : "অ্যাপ",
    "Settings" : "সেটিংস",
    "Log out" : "প্রস্থান",
    "Accounts" : "Accounts",
    "Email" : "ইমেইল",
    "Phone" : "ফোন",
    "Website" : "ওয়েবসাইট",
    "Address" : "ঠিকানা",
    "About" : "সমপরকে",
    "You are not allowed to share %s" : "আপনি %s ভাগাভাগি করতে পারবেননা",
    "Sunday" : "রবিবার",
    "Monday" : "সোমবার",
    "Tuesday" : "মঙ্গলবার",
    "Wednesday" : "বুধবার",
    "Thursday" : "বৃহস্পতিবার",
    "Friday" : "শুক্রবার",
    "Saturday" : "শনিবার",
    "Sun." : "রবি.",
    "Mon." : "সোম.",
    "Tue." : "মঙ্গল.",
    "Wed." : "বুধ.",
    "Thu." : "বৃহঃ.",
    "Fri." : "শুক্র.",
    "Sat." : "শনি.",
    "January" : "জানুয়ারি",
    "February" : "ফেব্রুয়ারি",
    "March" : "মার্চ",
    "April" : "এপ্রিল",
    "May" : "মে",
    "June" : "জুন",
    "July" : "জুলাই",
    "August" : "অগাষ্ট",
    "September" : "সেপ্টেম্বর",
    "October" : "অক্টোবর",
    "November" : "নভেম্বর",
    "December" : "ডিসেম্বর",
    "Jan." : "জানু.",
    "Feb." : "ফেব্রু.",
    "Mar." : "মার্চ.",
    "Apr." : "এপ্রিল.",
    "May." : "মে.",
    "Jun." : "জুন.",
    "Jul." : "জুলাই.",
    "Aug." : "অগাস্ট.",
    "Sep." : "সেপ্টে.",
    "Oct." : "অক্টো.",
    "Nov." : "নভে.",
    "Dec." : "ডিসে.",
    "Application is not enabled" : "অ্যাপ্লিকেসনটি সক্রিয় নয়",
    "Authentication error" : "অনুমোদন ঘটিত সমস্যা",
    "Token expired. Please reload page." : "টোকেন মেয়াদোত্তীর্ণ। দয়া করে পৃষ্ঠাটি পূনরায় লোড করুন।"
},
"nplurals=2; plural=(n != 1);");
